==> cdktf-provider-google-13.1.0-sources.jar: com/hashicorp/cdktf/providers/google/data_google_cloud_run_v2_service/DataGoogleCloudRunV2ServiceTemplateVolumesOutputReference.java <==
package com.hashicorp.cdktf.providers.google.data_google_cloud_run_v2_service;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-17T04:17:40.496Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.google.$Module.class, fqn = "@cdktf/provider-google.dataGoogleCloudRunV2Service.DataGoogleCloudRunV2ServiceTemplateVolumesOutputReference")
public class DataGoogleCloudRunV2ServiceTemplateVolumesOutputReference extends com.hashicorp.cdktf.ComplexObject {

    protected DataGoogleCloudRunV2ServiceTemplateVolumesOutputReference(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected DataGoogleCloudRunV2ServiceTemplateVolumesOutputReference(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param terraformResource The parent resource. This parameter is required.
     * @param terraformAttribute The attribute on the parent resource this class is referencing. This parameter is required.
     * @param complexObjectIndex the index of this item in the list. This parameter is required.
     * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index). This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public DataGoogleCloudRunV2ServiceTemplateVolumesOutputReference(final @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.IInterpolatingParent terraformResource, final @org.jetbrains.annotations.NotNull java.lang.String terraformAttribute, final @org.jetbrains.annotations.NotNull java.lang.Number complexObjectIndex, final @org.jetbrains.annotations.NotNull java.lang.Boolean complexObjectIsFromSet) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(terraformResource, "terraformResource is required"), java.util.Objects.requireNonNull(terraformAttribute, "terraformAttribute is required"), java.util.Objects.requireNonNull(complexObjectIndex, "complexObjectIndex is required"), java.util.Objects.requireNonNull(complexObjectIsFromSet, "complexObjectIsFromSet is required") });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.google.data_google_cloud_run_v2_service.DataGoogleCloudRunV2ServiceTemplateVolumesCloudSqlInstanceList getCloudSqlInstance() {
        return software.amazon.jsii.Kernel.get(this, "cloudSqlInstance", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.google.data_google_cloud_run_v2_service.DataGoogleCloudRunV2ServiceTemplateVolumesCloudSqlInstanceList.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.String getName() {
        return software.amazon.jsii.Kernel.get(this, "name", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.google.data_google_cloud_run_v2_service.DataGoogleCloudRunV2ServiceTemplateVolumesSecretList getSecret() {
        return software.amazon.jsii.Kernel.get(this, "secret", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.google.data_google_cloud_run_v2_service.DataGoogleCloudRunV2ServiceTemplateVolumesSecretList.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.google.data_google_cloud_run_v2_service.DataGoogleCloudRunV2ServiceTemplateVolumes getInternalValue() {
        return software.amazon.jsii.Kernel.get(this, "internalValue", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.google.data_google_cloud_run_v2_service.DataGoogleCloudRunV2ServiceTemplateVolumes.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void setInternalValue(final @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.google.data_google_cloud_run_v2_service.DataGoogleCloudRunV2ServiceTemplateVolumes value) {
        software.amazon.jsii.Kernel.set(this, "internalValue", value);
    }
}

==> cdktf-provider-google-13.13.0-sources.jar: com/hashicorp/cdktf/providers/google/data_google_cloud_run_v2_service/DataGoogleCloudRunV2ServiceTemplateVolumesOutputReference.java <==
package com.hashicorp.cdktf.providers.google.data_google_cloud_run_v2_service;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.96.0 (build 921e240)", date = "2024-04-09T03:36:14.468Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.google.$Module.class, fqn = "@cdktf/provider-google.dataGoogleCloudRunV2Service.DataGoogleCloudRunV2ServiceTemplateVolumesOutputReference")
public class DataGoogleCloudRunV2ServiceTemplateVolumesOutputReference extends com.hashicorp.cdktf.ComplexObject {

    protected DataGoogleCloudRunV2ServiceTemplateVolumesOutputReference(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected DataGoogleCloudRunV2ServiceTemplateVolumesOutputReference(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param terraformResource The parent resource. This parameter is required.
     * @param terraformAttribute The attribute on the parent resource this class is referencing. This parameter is required.
     * @param complexObjectIndex the index of this item in the list. This parameter is required.
     * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index). This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public DataGoogleCloudRunV2ServiceTemplateVolumesOutputReference(final @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.IInterpolatingParent terraformResource, final @org.jetbrains.annotations.NotNull java.lang.String terraformAttribute, final @org.jetbrains.annotations.NotNull java.lang.Number complexObjectIndex, final @org.jetbrains.annotations.NotNull java.lang.Boolean complexObjectIsFromSet) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(terraformResource, "terraformResource is required"), java.util.Objects.requireNonNull(terraformAttribute, "terraformAttribute is required"), java.util.Objects.requireNonNull(complexObjectIndex, "complexObjectIndex is required"), java.util.Objects.requireNonNull(complexObjectIsFromSet, "complexObjectIsFromSet is required") });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.google.data_google_cloud_run_v2_service.DataGoogleCloudRunV2ServiceTemplateVolumesCloudSqlInstanceList getCloudSqlInstance() {
        return software.amazon.jsii.Kernel.get(this, "cloudSqlInstance", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.google.data_google_cloud_run_v2_service.DataGoogleCloudRunV2ServiceTemplateVolumesCloudSqlInstanceList.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.google.data_google_cloud_run_v2_service.DataGoogleCloudRunV2ServiceTemplateVolumesGcsList getGcs() {
        return software.amazon.jsii.Kernel.get(this, "gcs", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.google.data_google_cloud_run_v2_service.DataGoogleCloudRunV2ServiceTemplateVolumesGcsList.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.String getName() {
        return software.amazon.jsii.Kernel.get(this, "name", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.google.data_google_cloud_run_v2_service.DataGoogleCloudRunV2ServiceTemplateVolumesNfsList getNfs() {
        return software.amazon.jsii.Kernel.get(this, "nfs", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.google.data_google_cloud_run_v2_service.DataGoogleCloudRunV2ServiceTemplateVolumesNfsList.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.google.data_google_cloud_run_v2_service.DataGoogleCloudRunV2ServiceTemplateVolumesSecretList getSecret() {
        return software.amazon.jsii.Kernel.get(this, "secret", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.google.data_google_cloud_run_v2_service.DataGoogleCloudRunV2ServiceTemplateVolumesSecretList.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.google.data_google_cloud_run_v2_service.DataGoogleCloudRunV2ServiceTemplateVolumes getInternalValue() {
        return software.amazon.jsii.Kernel.get(this, "internalValue", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.google.data_google_cloud_run_v2_service.DataGoogleCloudRunV2ServiceTemplateVolumes.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void setInternalValue(final @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.google.data_google_cloud_run_v2_service.DataGoogleCloudRunV2ServiceTemplateVolumes value) {
        software.amazon.jsii.Kernel.set(this, "internalValue", value);
    }
}
